import axios from '@/http';
import { parseSvg } from '@meta2d/svg';
import { cdn } from './api';

const baseurl = import.meta.env.VITE_BASEURL || '/';

export function filename(str: string) {
  const i = str.lastIndexOf('.');
  return str.substring(0, i);
}

export async function getFolders(name: string, isSvg?: boolean) {
  const path = 'v/' + name;
  const folders: any = await axios.post('/api/assets/folders', {
    path,
  });
  if (!folders) {
    return [];
  }

  const files: any = await axios.post('/api/assets/files', {
    path,
  });

  const results = [];
  for (const item of folders.list) {
    const list = [];
    for (const f of files.list) {
      if (f.indexOf(item) >= 0) {
        const elem: any = {
          name: filename(f.replace(path + '/' + item + '/', '')),
          image: cdn + '/' + f.replace('v/', ''),
          isSvg,
        };
        list.push(elem);
      }
    }

    results.push({ name: item, list });
  }

  return results;
}

export async function getFiles(folder: string) {
  if (folder[folder.length - 1] !== '/') {
    folder += '/';
  }
  const files = (await axios.get(folder)) as any[];
  if (!files || !files.map) {
    return [];
  }
  return files.map((f) => {
    let fname = filename(f.name);
    return {
      name: globalThis.fileJson
        ? globalThis.fileJson[fname]
          ? globalThis.fileJson[fname]
          : fname
        : fname,
      pinyin: globalThis.fileJson ? fname : null,
      image: cdn + folder + f.name,
    };
  });
}

export async function makeSvg(elem: any) {
  const svgDom: string = await axios.get(elem.image);
  let _svgDom = svgDom.replaceAll('#333;', '#fff;');
  elem.svg = _svgDom;
  elem.data = parseSvg(_svgDom);
}

export async function getIcons(folder: string) {
  const files = (await axios.get(folder)) as any[];
  return await Promise.all(files.map((f) => svgToPens(f, folder)));
}

async function svgToPens(f: any, folder: string) {
  const _name = filename(f.name);
  const name = globalThis.fileJson
    ? globalThis.fileJson[_name]
      ? globalThis.fileJson[_name]
      : _name
    : _name;
  const image = cdn + folder + f.name;
  const svgDom: string = await axios.get(image);
  let _svgDom = svgDom.replace('stroke:#333;', 'stroke:#bdc7db;');
  const data = parseSvg(_svgDom);
  return {
    name,
    pinyin: globalThis.fileJson ? _name : null,
    componentDatas: data,
    svg: _svgDom,
    component: true,
  };
}
